@@ -22,23 +22,24 @@ import shutil
 import sys
 import time
 from collections import defaultdict
+from contextlib import chdir
 from functools import partial
 from itertools import chain
+from os.path import join as pjoin, normpath
 from tempfile import TemporaryFile
 
 from snakeoil import data_source, klass
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
-from snakeoil.contexts import chdir
 from snakeoil.currying import post_curry, pretty_docs
 from snakeoil.fileutils import touch
-from snakeoil.osutils import ensure_dirs, listdir_files, normpath, pjoin
+from snakeoil.osutils import ensure_dirs, listdir_files
 from snakeoil.process.spawn import (
     is_sandbox_capable,
     is_userpriv_capable,
     spawn,
     spawn_bash,
 )
-from snakeoil.sequences import iflatten_instance, iter_stable_unique
+from snakeoil.sequences import iflatten_instance, unique_stable
 
 from .. import const
 from ..log import logger
@@ -81,7 +82,7 @@ class ebd:
 
         if not hasattr(self, "observer"):
             self.observer = observer
-        if not self.eapi.is_supported:
+        if not self.eapi.supported:
             raise TypeError(f"package {pkg} uses unsupported EAPI: {str(self.eapi)!r}")
 
         if initial_env is not None:
@@ -400,7 +401,7 @@ class ebd:
                 )
             if not ebd.expect("next"):
                 chuck_UnhandledCommand(
-                    ebd, "bashrc transfer, didn't receive 'next' response.  " "failure?"
+                    ebd, "bashrc transfer, didn't receive 'next' response. failure?"
                 )
         ebd.write("end_request")
 
@@ -758,7 +759,7 @@ class buildable(ebd, setup_mixin, format.build):
         self.env["PATH"] = os.pathsep.join(path)
 
         # ordering must match appearance order in SRC_URI per PMS
-        self.env["A"] = " ".join(iter_stable_unique(pkg.distfiles))
+        self.env["A"] = " ".join(unique_stable(pkg.distfiles))
 
         if self.eapi.options.has_AA:
             pkg = self.pkg
