@@ -12,10 +12,11 @@ __all__ = (
 
 import operator
 import os
+from os.path import join as pjoin
 
 from snakeoil.cli.input import userquery
 from snakeoil.mappings import defaultdictkey
-from snakeoil.osutils import pjoin, sizeof_fmt
+from snakeoil.osutils import sizeof_fmt
 from snakeoil.sequences import iflatten_instance
 from snakeoil.strings import pluralism
 
