@@ -23,7 +23,7 @@ from functools import partial
 from itertools import chain
 
 from snakeoil import mappings
-from snakeoil.klass import alias_method, generic_equality
+from snakeoil.klass import alias_method, GenericEquality
 from snakeoil.sequences import iflatten_instance
 
 from ..restrictions import boolean, packages, restriction
@@ -66,8 +66,14 @@ def optimize_incrementals(sequence):
                 finalized.add(item)
 
 
-def incremental_chunked(orig, iterables):
+def incremental_chunked(orig: set[str], iterables):
     for cinst in iterables:
+        if "*" in cinst.neg:  # remove all previous set flags
+            orig.clear()
+        for flag in cinst.neg:
+            if flag.endswith("_*"):  # remove previous USE_EXPAND
+                drop = [f for f in orig if f.startswith(flag[:-2])]
+                orig.difference_update(drop)
         orig.difference_update(cinst.neg)
         orig.update(cinst.pos)
 
@@ -135,8 +141,7 @@ def incremental_expansion_license(
 
 
 class IncrementalsDict(mappings.DictMixin):
-
-    disable_py3k_rewriting = True
+    __slots__ = ("_dict", "_incrementals")
 
     def __init__(self, incrementals, **kwds):
         self._incrementals = incrementals
@@ -161,8 +166,7 @@ class IncrementalsDict(mappings.DictMixin):
     del x, s
 
 
-class collapsed_restrict_to_data(metaclass=generic_equality):
-
+class collapsed_restrict_to_data(GenericEquality):
     __attr_comparison__ = ("defaults", "freeform", "atoms", "__class__")
     incremental = True
 
@@ -379,8 +383,7 @@ def _build_cp_atom_payload(sequence, restrict, payload_form=False):
     return tuple(new_l)
 
 
-class ChunkedDataDict(metaclass=generic_equality):
-
+class ChunkedDataDict(GenericEquality):
     __attr_comparison__ = ("_global_settings", "_dict")
 
     def __init__(self):
