@@ -13,11 +13,12 @@ import errno
 import os
 import sys
 from collections import OrderedDict
+from os.path import join as pjoin
 
 from snakeoil.bash import read_bash_dict
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
 from snakeoil.mappings import DictMixin, ImmutableDict
-from snakeoil.osutils import listdir_files, pjoin
+from snakeoil.osutils import listdir_files
 
 from .. import const
 from .. import exceptions as base_errors
@@ -42,7 +43,7 @@ def my_convert_hybrid(manager, val, arg_type):
 
 
 @configurable(
-    {"ebuild_repo": "ref:repo", "vdb": "ref:repo", "profile": "ref:profile"},
+    types={"ebuild_repo": "ref:repo", "vdb": "ref:repo", "profile": "ref:profile"},
     typename="pkgset",
 )
 def SecurityUpgradesViaProfile(ebuild_repo, vdb, profile):
@@ -93,6 +94,7 @@ class ParseConfig(configparser.ConfigParser):
 class PortageConfig(DictMixin):
     """Support for portage's config file layout."""
 
+    __slots__ = ("_config", "dir", "root", "features")
     _supported_repo_types = {}
 
     def __init__(self, location=None, profile_override=None, **kwargs):
@@ -153,7 +155,7 @@ class PortageConfig(DictMixin):
 
         self.root = kwargs.pop("root", make_conf.get("ROOT", "/"))
         gentoo_mirrors = [
-            x.rstrip("/") + "/distfiles"
+            f"{x.rstrip('/')}/distfiles"
             for x in make_conf.pop("GENTOO_MIRRORS", "").split()
         ]
 
@@ -172,24 +174,7 @@ class PortageConfig(DictMixin):
             }
         )
 
-        try:
-            repos_conf_defaults, repos_conf = self.load_repos_conf(
-                pjoin(self.dir, "repos.conf")
-            )
-        except config_errors.ParsingError as e:
-            if not getattr(getattr(e, "exc", None), "errno", None) == errno.ENOENT:
-                raise
-            try:
-                # fallback to defaults provided by pkgcore
-                repos_conf_defaults, repos_conf = self.load_repos_conf(
-                    pjoin(const.CONFIG_PATH, "repos.conf")
-                )
-            except IGNORED_EXCEPTIONS:
-                raise
-            except Exception as e:
-                raise config_errors.ParsingError(
-                    "failed to find a usable repos.conf"
-                ) from e
+        repos_conf_defaults, repos_conf = self.load_repos_conf()
 
         self["ebuild-repo-common"] = basics.AutoConfigSection(
             {
@@ -230,10 +215,10 @@ class PortageConfig(DictMixin):
 
         self._make_repo_syncers(repos_conf, make_conf)
         if repos:
-            self["repo-stack"] = basics.FakeIncrementalDictConfigSection(
+            self["repo-stack"] = basics.DictConfigSection(
                 my_convert_hybrid,
                 {
-                    "class": "pkgcore.repository.multiplex.config_tree",
+                    "class": "pkgcore.repository.multiplex.tree",
                     "repos": tuple(repos),
                 },
             )
@@ -265,9 +250,7 @@ class PortageConfig(DictMixin):
             }
         )
 
-        self["livefs"] = basics.FakeIncrementalDictConfigSection(
-            my_convert_hybrid, make_conf
-        )
+        self["livefs"] = basics.DictConfigSection(my_convert_hybrid, make_conf)
 
     def __setitem__(self, key, value):
         self._config[key] = value
@@ -326,15 +309,37 @@ class PortageConfig(DictMixin):
                 return
 
             if incrementals:
-                for key in econst.incrementals:
+                for key in profiles.INCREMENTALS:
                     if key in vars_dict and key in new_vars:
                         new_vars[key] = f"{vars_dict[key]} {new_vars[key]}"
             # quirk of read_bash_dict; it returns only what was mutated.
             vars_dict.update(new_vars)
 
+    def load_repos_conf(self) -> tuple[dict, dict]:
+        """parse and return repos.conf content, tracing the default and the fallback location"""
+        try:
+            repos_conf_defaults, repos_conf = self.parse_repos_conf_path(
+                pjoin(self.dir, "repos.conf")
+            )
+        except config_errors.ParsingError as e:
+            if not getattr(getattr(e, "exc", None), "errno", None) == errno.ENOENT:
+                raise
+            try:
+                # fallback to defaults provided by pkgcore
+                repos_conf_defaults, repos_conf = self.parse_repos_conf_path(
+                    pjoin(const.CONFIG_PATH, "repos.conf")
+                )
+            except IGNORED_EXCEPTIONS:
+                raise
+            except Exception as e:
+                raise config_errors.ParsingError(
+                    "failed to find a usable repos.conf"
+                ) from e
+        return repos_conf_defaults, repos_conf
+
     @classmethod
-    def load_repos_conf(cls, path):
-        """parse repos.conf files
+    def parse_repos_conf_path(cls, path: str):
+        """parse repos.conf files from a given entrypoint
 
         Args:
             path (str): path to the repos.conf which can be a regular file or
@@ -372,9 +377,7 @@ class PortageConfig(DictMixin):
                 ) from e
 
             if defaults and main_defaults:
-                logger.warning(
-                    f"repos.conf: parsing {fp!r}: overriding DEFAULT section"
-                )
+                logger.warning("repos.conf: parsing %r: overriding DEFAULT section", fp)
             main_defaults.update(defaults)
 
             if not had_repo_conf and not repo_confs:
@@ -385,15 +388,16 @@ class PortageConfig(DictMixin):
             for name, repo_conf in repo_confs.items():
                 if name in repos:
                     logger.warning(
-                        f"repos.conf: parsing {fp!r}: overriding {name!r} repo"
+                        "repos.conf: parsing %r: overriding %r repo", fp, name
                     )
 
                 # ignore repo if location is unset
                 location = repo_conf.get("location", None)
                 if location is None:
                     logger.warning(
-                        f"repos.conf: parsing {fp!r}: "
-                        f"{name!r} repo missing location setting, ignoring repo"
+                        "repos.conf: parsing %r: %r repo missing location setting, ignoring repo",
+                        fp,
+                        name,
                     )
                     continue
                 location = os.path.expanduser(location)
@@ -542,13 +546,11 @@ class PortageConfig(DictMixin):
         except FileNotFoundError:
             pass
 
-    def _find_profile_path(self, profile_override):
+    def _find_profile_path(self, profile_override) -> tuple[str, bool]:
         if profile_override is None:
             make_profile = pjoin(self.dir, "make.profile")
             if not os.path.islink(make_profile):
-                raise config_errors.UserConfigError(
-                    f"invalid symlink: {make_profile!r}"
-                )
+                return make_profile, True
             path = os.path.realpath(make_profile)
         else:
             path = os.path.realpath(profile_override)
@@ -560,15 +562,17 @@ class PortageConfig(DictMixin):
                 raise config_errors.UserConfigError(
                     f"nonexistent profile: {profile_override!r}"
                 )
-        return path
+        return path, False
 
     def _add_profile(self, profile_override=None):
-        profile = self._find_profile_path(profile_override)
-        paths = profiles.OnDiskProfile.split_abspath(profile)
+        profile, was_symlink = self._find_profile_path(profile_override)
+        if was_symlink:
+            paths = profile.rsplit(os.path.sep, 1)
+        else:
+            paths = profiles.OnDiskProfile.split_abspath(profile)
         if paths is None:
             raise config_errors.UserConfigError(
-                "%r expands to %r, but no profile detected"
-                % (pjoin(self.dir, "make.profile"), profile)
+                f"{pjoin(self.dir, 'make.profile')!r} expands to {profile!r}, but no profile detected"
             )
 
         user_profile_path = pjoin(self.dir, "profile")
@@ -579,6 +583,7 @@ class PortageConfig(DictMixin):
                     "parent_path": paths[0],
                     "parent_profile": paths[1],
                     "user_path": user_profile_path,
+                    "load_profile_base": not was_symlink,
                 }
             )
         else:
@@ -587,6 +592,7 @@ class PortageConfig(DictMixin):
                     "class": "pkgcore.ebuild.profiles.OnDiskProfile",
                     "basepath": paths[0],
                     "profile": paths[1],
+                    "load_profile_base": not was_symlink,
                 }
             )
 
