@@ -23,18 +23,19 @@ import platform
 import subprocess
 from collections import namedtuple
 from itertools import chain
+from os.path import join as pjoin
 from sys import intern
 
 from lxml import etree
 from snakeoil import klass, mappings
-from snakeoil.bash import BashParseError, iter_read_bash, read_dict
+from snakeoil.bash import BashParseError, read_bash, read_dict
 from snakeoil.caching import WeakInstMeta
 from snakeoil.currying import post_curry
 from snakeoil.fileutils import readfile, readlines
-from snakeoil.osutils import listdir, listdir_files, pjoin
+from snakeoil.osutils import listdir_files
 from snakeoil.osutils.mount import umount
 from snakeoil.process.namespaces import simple_unshare
-from snakeoil.sequences import iter_stable_unique
+from snakeoil.sequences import unique_stable
 from snakeoil.strings import pluralism
 
 from ..config.hint import ConfigHint
@@ -629,7 +630,7 @@ class Profiles(klass.ImmutableInstance):
         l = []
         fp = pjoin(profiles_base, "profiles.desc")
         try:
-            for lineno, line in iter_read_bash(fp, enum_line=True):
+            for lineno, line in read_bash(fp, enum_line=True):
                 try:
                     arch, profile, status = line.split()
                 except ValueError:
@@ -773,16 +774,14 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         except OSError as e:
             raise repo_errors.InitializationError(str(e))
 
-        if not self.eapi.is_supported:
+        if not self.eapi.supported:
             raise repo_errors.UnsupportedRepo(self)
 
     def _parse_config(self):
         """Load data from the repo's metadata/layout.conf file."""
         path = pjoin(self.location, self.layout_offset)
         data = read_dict(
-            iter_read_bash(
-                readlines(path, strip_whitespace=True, swallow_missing=True)
-            ),
+            read_bash(readlines(path, strip_whitespace=True, swallow_missing=True)),
             source_isiter=True,
             strip=True,
             filename=path,
@@ -795,14 +794,14 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         hashes = data.get("manifest-hashes", "").lower().split()
         if hashes:
             hashes = ["size"] + hashes
-            hashes = tuple(iter_stable_unique(hashes))
+            hashes = tuple(unique_stable(hashes))
         else:
             hashes = self.default_hashes
 
         required_hashes = data.get("manifest-required-hashes", "").lower().split()
         if required_hashes:
             required_hashes = ["size"] + required_hashes
-            required_hashes = tuple(iter_stable_unique(required_hashes))
+            required_hashes = tuple(unique_stable(required_hashes))
         else:
             required_hashes = self.default_required_hashes
 
@@ -829,7 +828,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
             _missing_masters = True
             masters = ()
         else:
-            masters = tuple(iter_stable_unique(masters.split()))
+            masters = tuple(unique_stable(masters.split()))
         sf(self, "_missing_masters", _missing_masters)
         sf(self, "masters", masters)
         aliases = data.get("aliases", "").split() + [
@@ -838,41 +837,41 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
             self.pms_repo_name,
             self.location,
         ]
-        sf(self, "aliases", tuple(filter(None, iter_stable_unique(aliases))))
+        sf(self, "aliases", tuple(filter(None, unique_stable(aliases))))
         sf(
             self,
             "eapis_deprecated",
-            tuple(iter_stable_unique(data.get("eapis-deprecated", "").split())),
+            tuple(unique_stable(data.get("eapis-deprecated", "").split())),
         )
         sf(
             self,
             "eapis_banned",
-            tuple(iter_stable_unique(data.get("eapis-banned", "").split())),
+            tuple(unique_stable(data.get("eapis-banned", "").split())),
         )
         sf(
             self,
             "eapis_testing",
-            tuple(iter_stable_unique(data.get("eapis-testing", "").split())),
+            tuple(unique_stable(data.get("eapis-testing", "").split())),
         )
         sf(
             self,
             "profile_eapis_deprecated",
-            tuple(iter_stable_unique(data.get("profile-eapis-deprecated", "").split())),
+            tuple(unique_stable(data.get("profile-eapis-deprecated", "").split())),
         )
         sf(
             self,
             "profile_eapis_banned",
-            tuple(iter_stable_unique(data.get("profile-eapis-banned", "").split())),
+            tuple(unique_stable(data.get("profile-eapis-banned", "").split())),
         )
         sf(
             self,
             "properties_allowed",
-            tuple(iter_stable_unique(data.get("properties-allowed", "").split())),
+            tuple(unique_stable(data.get("properties-allowed", "").split())),
         )
         sf(
             self,
             "restrict_allowed",
-            tuple(iter_stable_unique(data.get("restrict-allowed", "").split())),
+            tuple(unique_stable(data.get("restrict-allowed", "").split())),
         )
         sf(self, "sign_commits", data.get("sign-commits", "false").lower() == "true")
 
@@ -911,7 +910,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
     def known_arches(self):
         """All valid KEYWORDS for the repo."""
         try:
-            return frozenset(iter_read_bash(pjoin(self.profiles_base, "arch.list")))
+            return frozenset(read_bash(pjoin(self.profiles_base, "arch.list")))
         except FileNotFoundError:
             return frozenset()
 
@@ -924,7 +923,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         fp = pjoin(self.profiles_base, "arches.desc")
         d = {"stable": set(), "transitional": set(), "testing": set()}
         try:
-            for lineno, line in iter_read_bash(fp, enum_line=True):
+            for lineno, line in read_bash(fp, enum_line=True):
                 try:
                     arch, status = line.split()
                 except ValueError:
@@ -1020,7 +1019,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         line = None
         fp = pjoin(self.profiles_base, name)
         try:
-            for line in iter_read_bash(fp):
+            for line in read_bash(fp):
                 try:
                     key, val = line.split(None, 1)
                     key = converter(key)
@@ -1041,7 +1040,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         result = True
         try:
             # any files existing means it's not empty
-            result = not listdir(self.location)
+            result = not os.listdir(self.location)
             if result:
                 logger.debug(f"repo is empty: {self.location!r}")
         except FileNotFoundError:
