@@ -8,6 +8,7 @@ import locale
 import os
 from functools import partial, wraps
 from itertools import chain, filterfalse
+from os.path import join as pjoin
 from random import shuffle
 from sys import intern
 from weakref import WeakValueDictionary
@@ -16,24 +17,27 @@ from snakeoil import chksum, klass
 from snakeoil.bash import read_dict
 from snakeoil.containers import InvertedContains
 from snakeoil.data_source import local_source
+from snakeoil.fileutils import readlines_utf8
 from snakeoil.mappings import ImmutableDict
 from snakeoil.obj import make_kls
-from snakeoil.osutils import listdir_dirs, listdir_files, pjoin
-from snakeoil.sequences import iflatten_instance, stable_unique
+from snakeoil.osutils import listdir_dirs, listdir_files
+from snakeoil.sequences import iflatten_instance, unique_stable
 from snakeoil.strings import pluralism
 
 from .. import fetch
 from ..config.hint import ConfigHint, configurable
 from ..log import logger
-from ..operations import OperationError, repo as _repo_ops
+from ..operations import OperationError
+from ..operations import repo as _repo_ops
 from ..package import errors as pkg_errors
 from ..repository import configured, errors, prototype, util
 from ..repository.virtual import RestrictionRepo
 from ..restrictions import packages
 from ..util import packages as pkgutils
-from . import cpv, digest, ebd, ebuild_src
+from . import cpv, digest, ebd, ebuild_src, processor, repo_objs, restricts
 from . import eclass_cache as eclass_cache_mod
-from . import processor, repo_objs, restricts
+from . import errors as ebuild_errors
+from .atom import atom
 from .eapi import get_eapi
 
 
@@ -160,6 +164,18 @@ class repo_operations(_repo_ops.operations):
                 observer.info(f"generating manifest: {key}::{self.repo.repo_id}")
                 manifest.update(sorted(all_fetchables.values()), chfs=write_chksums)
 
+        # edge case: If all ebuilds for a package were masked bad,
+        # then it was filtered out of the iterator for the above loop,
+        # so we handle unreported bad packages here.
+        missed_bad_set = set()
+        for pkg in self.repo._bad_masked:
+            if pkg.key not in ret:
+                observer.error(
+                    f"{pkg.cpvstr}: {pkg.data.msg(verbosity=observer.verbosity)}"
+                )
+                missed_bad_set.add(pkg.key)
+        ret.update(missed_bad_set)
+
         return ret
 
 
@@ -214,7 +230,6 @@ class ProvidesRepo(util.SimpleTree):
             self.__dict__.update(kwds)
 
     class PkgProvided(ebuild_src.base):
-
         __slots__ = ("arches", "use")
 
         package_is_real = False
@@ -276,7 +291,7 @@ class UnconfiguredTree(prototype.tree):
     operations_kls = repo_operations
 
     pkgcore_config_type = ConfigHint(
-        {
+        types={
             "location": "str",
             "eclass_cache": "ref:eclass_cache",
             "masters": "refs:repo",
@@ -326,7 +341,7 @@ class UnconfiguredTree(prototype.tree):
             )
 
         # verify we support the repo's EAPI
-        if not self.is_supported:
+        if not self.supported:
             raise errors.UnsupportedRepo(self)
 
         if eclass_cache is None:
@@ -371,7 +386,7 @@ class UnconfiguredTree(prototype.tree):
     repo_name = klass.alias_attr("config.repo_name")
     aliases = klass.alias_attr("config.aliases")
     eapi = klass.alias_attr("config.eapi")
-    is_supported = klass.alias_attr("config.eapi.is_supported")
+    supported = klass.alias_attr("config.eapi.supported")
     external = klass.alias_attr("config.external")
     pkg_masks = klass.alias_attr("config.pkg_masks")
 
@@ -399,8 +414,10 @@ class UnconfiguredTree(prototype.tree):
             path_chunks = path.split(os.path.sep)
         else:
             path = os.path.realpath(os.path.abspath(path))
-            relpath = path[len(os.path.realpath(self.location)) :].strip("/")
-            path_chunks = relpath.split(os.path.sep)
+            if relpath := path[len(os.path.realpath(self.location)) :].strip("/"):
+                path_chunks = relpath.split(os.path.sep)
+            else:
+                path_chunks = ()
 
         if os.path.isfile(path):
             if not path.endswith(".ebuild"):
@@ -501,12 +518,7 @@ class UnconfiguredTree(prototype.tree):
             logger.error(f"failed listing categories: {e}")
         return ()
 
-    def _get_categories(self, *optional_category):
-        # why the auto return? current porttrees don't allow/support
-        # categories deeper then one dir.
-        if optional_category:
-            # raise KeyError
-            return ()
+    def _get_categories(self):
         categories = frozenset(
             chain.from_iterable(repo.config.categories for repo in self.trees)
         )
@@ -571,7 +583,7 @@ class UnconfiguredTree(prototype.tree):
             else:
                 # check pkgs for unsupported/invalid EAPIs and bad metadata
                 try:
-                    if not pkg.is_supported:
+                    if not pkg.supported:
                         exc = pkg_errors.MetadataException(
                             pkg, "eapi", f"EAPI '{pkg.eapi}' is not supported"
                         )
@@ -656,6 +668,32 @@ class UnconfiguredTree(prototype.tree):
             pkg_deprecated.update(repo.config.pkg_deprecated)
         return packages.OrRestriction(*pkg_deprecated)
 
+    @klass.jit_attr
+    def stabilization_groups(self):
+        """Return a mapping of stabilization groups to packages."""
+        base_dir = pjoin(self.location, "metadata", "stabilization-groups")
+        group_files = {
+            pjoin(dirname, file)
+            .removeprefix(base_dir + "/")
+            .removesuffix(".group"): pjoin(dirname, file)
+            for dirname, _dirs, files in os.walk(base_dir)
+            for file in files
+            if file.endswith(".group")
+        }
+        stabilization_groups = {}
+        for group_name, group_file in group_files.items():
+            pkgs = set()
+            for lineno, line in enumerate(readlines_utf8(group_file), 1):
+                try:
+                    if line := line.split("#", maxsplit=1)[0].strip():
+                        pkgs.add(atom(line))
+                except ebuild_errors.MalformedAtom as exc:
+                    logger.error(
+                        f"{group_file.removeprefix(self.location)}, line {lineno}: parsing error: {exc}"
+                    )
+            stabilization_groups[group_name] = frozenset(pkgs)
+        return ImmutableDict(stabilization_groups)
+
     def _regen_operation_helper(self, **kwds):
         return _RegenOpHelper(
             self,
@@ -854,7 +892,7 @@ class ConfiguredTree(configured.tree):
     @_wrap_attr(config_wrappables)
     def _distfiles(self, raw_pkg_distfiles, enabled_use, pkg):
         """Distfiles used by a package."""
-        return tuple(stable_unique(raw_pkg_distfiles.evaluate_depset(enabled_use)))
+        return tuple(unique_stable(raw_pkg_distfiles.evaluate_depset(enabled_use)))
 
     @_wrap_attr(config_wrappables)
     def _user_patches(self, _raw_pkg_patches, _enabled_use, pkg):
