@@ -18,11 +18,12 @@ __all__ = (
 
 import fnmatch
 import os
+from os.path import join as pjoin, normpath
 
 from snakeoil.bash import read_bash_dict
 from snakeoil.fileutils import AtomicWriteFile
-from snakeoil.osutils import listdir_files, normpath, pjoin
-from snakeoil.sequences import iflatten_instance, stable_unique
+from snakeoil.osutils import listdir_files
+from snakeoil.sequences import iflatten_instance, unique_stable
 
 from .. import os_data
 from ..fs import livefs
@@ -175,7 +176,6 @@ def perform_env_update(root, skip_ldso_update=False):
 
 
 class env_update(triggers.base):
-
     required_csets = ()
     priority = 5
     _hooks = ("post_unmerge", "post_merge")
@@ -206,13 +206,13 @@ def gen_config_protect_filter(offset, extra_protects=(), extra_disables=()):
 
     r = [
         values.StrGlobMatch(normpath(x).rstrip("/") + "/")
-        for x in set(stable_unique(collapsed_d["CONFIG_PROTECT"] + ["/etc"]))
+        for x in set(unique_stable(collapsed_d["CONFIG_PROTECT"] + ["/etc"]))
     ]
     if len(r) > 1:
         r = values.OrRestriction(*r)
     else:
         r = r[0]
-    neg = stable_unique(collapsed_d["CONFIG_PROTECT_MASK"])
+    neg = unique_stable(collapsed_d["CONFIG_PROTECT_MASK"])
     if neg:
         if len(neg) == 1:
             r2 = values.StrGlobMatch(normpath(neg[0]).rstrip("/") + "/", negate=True)
@@ -231,18 +231,17 @@ def gen_collision_ignore_filter(offset, extra_ignores=()):
     ignored.extend(extra_ignores)
     ignored.extend(["*/.keep", "*/.keep_*"])
 
-    ignored = stable_unique(ignored)
+    ignored = unique_stable(ignored)
     for i, x in enumerate(ignored):
         if not x.endswith("/*") and os.path.isdir(x):
             ignored[i] = ignored.rstrip("/") + "/*"
-    ignored = [values.StrRegex(fnmatch.translate(x)) for x in stable_unique(ignored)]
+    ignored = [values.StrRegex(fnmatch.translate(x)) for x in unique_stable(ignored)]
     if len(ignored) == 1:
         return ignored[0]
     return values.OrRestriction(*ignored)
 
 
 class ConfigProtectInstall(triggers.base):
-
     required_csets = ("install_existing", "install")
     priority = 100
     _hooks = ("pre_merge",)
@@ -324,7 +323,6 @@ class ConfigProtectInstall(triggers.base):
 
 
 class ConfigProtectInstall_restore(triggers.base):
-
     required_csets = ("install",)
     priority = 10
     _hooks = ("post_merge",)
@@ -344,7 +342,6 @@ class ConfigProtectInstall_restore(triggers.base):
 
 
 class ConfigProtectUninstall(triggers.base):
-
     required_csets = ("uninstall_existing", "uninstall")
     _hooks = ("pre_unmerge",)
 
@@ -369,7 +366,6 @@ class ConfigProtectUninstall(triggers.base):
 
 
 class UninstallIgnore(triggers.base):
-
     required_csets = {
         const.REPLACE_MODE: ("uninstall_existing", "uninstall", "old_cset"),
         const.UNINSTALL_MODE: ("uninstall_existing", "uninstall"),
@@ -398,7 +394,6 @@ class UninstallIgnore(triggers.base):
 
 
 class preinst_contents_reset(triggers.base):
-
     required_csets = ("new_cset",)
     priority = 1
     _hooks = ("pre_merge",)
@@ -518,7 +513,6 @@ class ProtectOwned(FileCollision):
 
 
 class install_into_symdir_protect(triggers.base):
-
     required_csets = {
         const.INSTALL_MODE: ("install", "install_existing"),
         const.REPLACE_MODE: ("install", "install_existing", "old_cset"),
@@ -557,7 +551,6 @@ class install_into_symdir_protect(triggers.base):
 
 
 class InfoRegen(triggers.InfoRegen):
-
     _label = "ebuild info regen"
 
     def register(self, engine):
@@ -601,7 +594,7 @@ class SFPerms(triggers.base):
             if x.mode & 0o4000:
                 if x.mode & 0o044:
                     engine.observer.warn(
-                        "sfperms: dropping group/world read " f"due to SetGID: {x!r}"
+                        f"sfperms: dropping group/world read due to SetGID: {x!r}"
                     )
                     resets.append(x.change_attributes(mode=x.mode & ~0o44))
             if x.mode & 0o2000:
@@ -635,7 +628,6 @@ def register_multilib_strict_trigger(opts):
 
 
 class FixImageSymlinks(triggers.base):
-
     required_csets = ("new_cset",)
     _hooks = ("pre_merge",)
 
