@@ -7,9 +7,9 @@ import time
 from collections import OrderedDict, defaultdict
 from functools import partial
 from operator import attrgetter
+from os.path import join as pjoin, normpath
 
-from snakeoil.klass import alias_method, generic_equality
-from snakeoil.osutils import normpath, pjoin
+from snakeoil.klass import alias_method, GenericEquality
 
 from . import fs
 
@@ -36,14 +36,13 @@ def check_instance(obj):
     return obj.location, obj
 
 
-class contentsSet(metaclass=generic_equality):
+class contentsSet(GenericEquality):
     """set of :class:`pkgcore.fs.fs.fsBase` objects"""
 
     __attr_comparison__ = ("_dict",)
     __dict_kls__ = dict
 
     def __init__(self, initial=None, mutable=True):
-
         """
         :param initial: initial fs objs for this set
         :type initial: sequence
@@ -66,7 +65,6 @@ class contentsSet(metaclass=generic_equality):
         return f"{name}([{contents}])"
 
     def add(self, obj):
-
         """
         add a new fs obj to the set
 
@@ -81,7 +79,6 @@ class contentsSet(metaclass=generic_equality):
         self._dict[obj.location] = obj
 
     def __delitem__(self, obj):
-
         """
         remove a fs obj to the set
 
