@@ -4,7 +4,8 @@ filesystem entry abstractions
 
 import fnmatch
 import stat
-from os.path import abspath, basename, dirname, realpath
+from functools import total_ordering
+from os.path import abspath, basename, dirname, join as pjoin, normpath, realpath
 from os.path import sep as path_seperator
 
 from snakeoil import klass
@@ -12,8 +13,8 @@ from snakeoil.chksum import get_chksums, get_handlers
 from snakeoil.compatibility import cmp
 from snakeoil.currying import post_curry, pretty_docs
 from snakeoil.data_source import local_source
+from snakeoil.klass import immutable
 from snakeoil.mappings import LazyFullValLoadDict
-from snakeoil.osutils import normpath, pjoin
 
 # goofy set of classes representating the fs objects pkgcore knows of.
 
@@ -41,9 +42,7 @@ def gen_doc_additions(init, slots):
 :param location: location (real or intended) for this entry
 :param strict: is this fully representative of the entry, or only partially
 :raise KeyError: if strict is enabled, and not all args are passed in
-""".split(
-            "\n"
-        )
+""".split("\n")
     else:
         d = init.__doc__.split("\n")
     init.__doc__ = "\n".join(k.lstrip() for k in d) + "\n".join(
@@ -51,7 +50,8 @@ def gen_doc_additions(init, slots):
     )
 
 
-class fsBase:
+@total_ordering
+class fsBase(immutable.Simple):
     """base class, all extensions must derive from this class"""
 
     __slots__ = ("location", "mtime", "mode", "uid", "gid")
@@ -64,19 +64,15 @@ class fsBase:
         if x.startswith("is") and x.islower() and not x.endswith("fs_obj")
     )
 
-    klass.inject_richcmp_methods_from_cmp(locals())
-    klass.inject_immutable_instance(locals())
-
     def __init__(self, location, strict=True, **d):
         d["location"] = normpath(location)
 
-        s = object.__setattr__
         if strict:
             for k in self.__attrs__:
-                s(self, k, d[k])
+                object.__setattr__(self, k, d[k])
         else:
             for k, v in d.items():
-                s(self, k, v)
+                object.__setattr__(self, k, v)
 
     gen_doc_additions(__init__, __attrs__)
 
@@ -133,8 +129,8 @@ class fsBase:
     def fnmatch(self, pattern):
         return fnmatch.fnmatch(self.location, pattern)
 
-    def __cmp__(self, other):
-        return cmp(self.location, other.location)
+    def __lt__(self, other):
+        return self.location < other.location
 
     def __str__(self):
         return self.location
