@@ -8,8 +8,9 @@ Shouldn't be accessed directly for the most part, use
 import errno
 import os
 from functools import partial
+from os.path import join as pjoin
 
-from snakeoil.osutils import ensure_dirs, pjoin, unlink_if_exists
+from snakeoil.osutils import ensure_dirs, unlink_if_exists
 from snakeoil.process.spawn import spawn
 
 from ..const import CP_BINARY
@@ -18,7 +19,6 @@ from .livefs import gen_obj
 
 
 def ensure_perms(d1, d2=None):
-
     """Enforce a fs objects attributes on the livefs.
 
     Attributes enforced are permissions, mtime, uid, gid.
@@ -36,7 +36,6 @@ def ensure_perms(d1, d2=None):
     if d2 is None:
         do_mode, do_chown, do_mtime = True, True, True
     else:
-
         do_mode = False
         try:
             if fs.isdir(d1) and fs.isdir(d2):
@@ -200,7 +199,6 @@ def do_link(src, trg):
 
 
 def merge_contents(cset, offset=None, callback=None):
-
     """
     merge a :class:`pkgcore.fs.contents.contentsSet` instance to the livefs
 
@@ -295,7 +293,6 @@ def merge_contents(cset, offset=None, callback=None):
 
 
 def unmerge_contents(cset, offset=None, callback=None):
-
     """
     unmerge a :obj:`pkgcore.fs.contents.contentsSet` instance to the livefs
 
