@@ -3,10 +3,10 @@ import subprocess
 import textwrap
 from collections.abc import MutableSet
 from datetime import datetime
+from os.path import join as pjoin
 
 from snakeoil import klass
 from snakeoil.fileutils import touch
-from snakeoil.osutils import pjoin
 
 import pytest
 
@@ -41,6 +41,8 @@ class GitRepo:
                 self.add(pjoin(self.path, ".init"), create=True)
 
     def run(self, cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL, **kwargs):
+        env = os.environ.copy()
+        env["HOME"] = self.path
         return subprocess.run(
             cmd,
             cwd=self.path,
@@ -48,10 +50,11 @@ class GitRepo:
             check=True,
             stdout=stdout,
             stderr=stderr,
+            env=env,
             **kwargs,
         )
 
-    def log(self, args):
+    def log(self, args: list[str]):
         """Run ``git log`` with given args and return a list of outputted lines."""
         p = self.run(["git", "log"] + args, stdout=subprocess.PIPE)
         return p.stdout.strip().splitlines()
@@ -72,7 +75,7 @@ class GitRepo:
     def __str__(self):
         return self.path
 
-    def commit(self, msg, signoff=False):
+    def commit(self, msg: str | list[str], signoff=False):
         """Make a commit to the repo."""
         if isinstance(msg, str):
             msg = msg.splitlines()
@@ -194,7 +197,7 @@ class EbuildRepo:
                 f.write(
                     textwrap.dedent(
                         f"""\
-                    masters = {' '.join(masters)}
+                    masters = {" ".join(masters)}
                     cache-formats =
                     thin-manifests = true
                 """
@@ -234,10 +237,10 @@ class EbuildRepo:
                 with open(pjoin(self.path, "profiles", p.path, "eapi"), "w") as f:
                     f.write(f"{p.eapi}\n")
 
-    def create_ebuild(self, cpvstr, data=None, **kwargs):
-        from pkgcore.ebuild import cpv as cpv_mod
+    def create_ebuild(self, cpvstr: str, data=None, **kwargs):
+        from pkgcore.ebuild.cpv import VersionedCPV
 
-        cpv = cpv_mod.VersionedCPV(cpvstr)
+        cpv = VersionedCPV(cpvstr)
         self._repo.notify_add_package(cpv)
         ebuild_dir = pjoin(self.path, cpv.category, cpv.package)
         os.makedirs(ebuild_dir, exist_ok=True)
@@ -260,17 +263,17 @@ class EbuildRepo:
                 """
                     )
                 )
-            f.write(f'EAPI="{eapi}"\n')
+            f.write(f"EAPI={eapi}\n\n")
             f.write(f'DESCRIPTION="{desc}"\n')
             f.write(f'HOMEPAGE="{homepage}"\n')
-            f.write(f'SLOT="{slot}"\n')
-
             if license:
                 f.write(f'LICENSE="{license}"\n')
                 # create a fake license
                 os.makedirs(pjoin(self.path, "licenses"), exist_ok=True)
                 touch(pjoin(self.path, "licenses", license))
 
+            f.write(f'SLOT="{slot}"\n')
+
             for k, v in kwargs.items():
                 # handle sequences such as KEYWORDS and IUSE
                 if isinstance(v, (tuple, list)):
