@@ -2,8 +2,9 @@
 base repository template
 """
 
-__all__ = ("CategoryIterValLazyDict", "PackageMapping", "VersionMapping", "tree")
+__all__ = ("CategoryLazyFrozenSet", "PackageMapping", "VersionMapping", "tree")
 
+import typing
 from pathlib import Path
 
 from snakeoil.klass import jit_attr
@@ -16,43 +17,33 @@ from ..restrictions import boolean, packages, restriction, values
 from ..restrictions.util import collect_package_restrictions
 
 
-class IterValLazyDict(LazyValDict):
+class CategoryLazyFrozenSet:
+    """Lazy frozenset for holding categories"""
 
-    __slots__ = ()
+    __slots__ = ("_get_values", "_values")
 
-    def __str__(self):
-        return str(list(self))
+    def __init__(self, get_values: typing.Callable[[], typing.Iterable[str]]):
+        self._get_values = get_values
+        self._values = None  # type: typing.Union[None, frozenset]
 
-    def force_regen(self, key):
-        if key in self._vals:
-            del self._vals[key]
-        else:
-            self._keys = tuple(x for x in self._keys if x != key)
+    def __iter__(self):
+        if self._values is None:
+            self._values = frozenset(self._get_values())
+        return iter(self._values)
 
+    def __contains__(self, cat: str):
+        if self._values is None:
+            self._values = frozenset(self._get_values())
+        return cat in self._values
 
-class CategoryIterValLazyDict(IterValLazyDict):
-
-    __slots__ = ()
-
-    def force_add(self, key):
-        if key not in self:
-            s = set(self._keys)
-            s.add(key)
-            self._keys = tuple(s)
-
-    def force_remove(self, key):
-        if key in self:
-            self._keys = tuple(x for x in self._keys if x != key)
-
-    __iter__ = IterValLazyDict.keys
-
-    def __contains__(self, key):
-        if self._keys_func is not None:
-            return key in list(self.keys())
-        return key in self._keys
+    def force_regen(self):
+        """wipe cached values to trigger a refresh"""
+        self._values = None
 
 
 class PackageMapping(DictMixin):
+    __slots__ = ("_cache", "_parent", "_pull_vals")
+
     def __init__(self, parent_mapping, pull_vals):
         self._cache = {}
         self._parent = parent_mapping
@@ -64,23 +55,22 @@ class PackageMapping(DictMixin):
             return o
         if key not in self._parent:
             raise KeyError(key)
-        self._cache[key] = vals = self._pull_vals(key)
+        self._cache[key] = vals = tuple(self._pull_vals(key))
         return vals
 
     def keys(self):
-        return self._parent.keys()
+        return iter(self._parent)
 
     def __contains__(self, key):
         return key in self._cache or key in self._parent
 
     def force_regen(self, cat):
-        try:
-            del self._cache[cat]
-        except KeyError:
-            pass
+        self._cache.pop(cat, None)
 
 
 class VersionMapping(DictMixin):
+    __slots__ = ("_cache", "_parent", "_pull_vals")
+
     def __init__(self, parent_mapping, pull_vals):
         self._cache = {}
         self._parent = parent_mapping
@@ -90,9 +80,9 @@ class VersionMapping(DictMixin):
         o = self._cache.get(key)
         if o is not None:
             return o
-        if not key[1] in self._parent.get(key[0], ()):
+        if key[1] not in self._parent.get(key[0], ()):
             raise KeyError(key)
-        val = self._pull_vals(key)
+        val = tuple(self._pull_vals(key))
         self._cache[key] = val
         return val
 
@@ -132,7 +122,7 @@ class tree:
     """
 
     raw_repo = None
-    is_supported = True
+    supported = True
     livefs = False
     package_class = None
     configured = True
@@ -141,9 +131,7 @@ class tree:
     pkg_masks = frozenset()
 
     def __init__(self, frozen=False):
-        self.categories = CategoryIterValLazyDict(
-            self._get_categories, self._get_categories
-        )
+        self.categories = CategoryLazyFrozenSet(self._get_categories)
         self.packages = PackageMapping(self.categories, self._get_packages)
         self.versions = VersionMapping(self.packages, self._get_versions)
 
@@ -155,16 +143,18 @@ class tree:
         """Return a configured form of the repository."""
         raise NotImplementedError(self, "configure")
 
-    def _get_categories(self, *args):
-        """this must return a list, or sequence"""
+    def _get_categories(self) -> frozenset[str] | typing.Iterable[str]:
+        """this must return an iterable or tuple of this repo's categories"""
         raise NotImplementedError(self, "_get_categories")
 
-    def _get_packages(self, category):
-        """this must return a list, or sequence"""
+    def _get_packages(self, category: str) -> tuple[str] | typing.Iterable[str]:
+        """Receives category and must return the packages of that cat.  Converted to tuple"""
         raise NotImplementedError(self, "_get_packages")
 
-    def _get_versions(self, package):
-        """this must return a list, or sequence"""
+    def _get_versions(
+        self, package: tuple[str, str]
+    ) -> tuple[str] | typing.Iterable[str]:
+        """Receives (cat/pkg) and must return the cp versions.  Converted to tuple"""
         raise NotImplementedError(self, "_get_versions")
 
     def __getitem__(self, cpv):
@@ -217,7 +207,6 @@ class tree:
             return False
 
     def has_match(self, atom, **kwds):
-
         kwds.pop("sorter", None)
         kwds.pop("yield_none", None)
 
@@ -480,7 +469,7 @@ class tree:
             wipe = list(self.packages[pkg.category]) == [pkg.package]
             self.packages.force_regen(pkg.category)
             if wipe:
-                self.categories.force_regen(pkg.category)
+                self.categories.force_regen()
         self.versions.force_regen(ver_key, tuple(l))
 
     def notify_add_package(self, pkg):
@@ -491,8 +480,7 @@ class tree:
         ver_key = (pkg.category, pkg.package)
         s = set(self.versions.get(ver_key, ()))
         s.add(pkg.fullver)
-        if pkg.category not in self.categories:
-            self.categories.force_add(pkg.category)
+        self.categories.force_regen()
         self.packages.force_regen(pkg.category)
         self.versions.force_regen(ver_key, tuple(s))
 
