@@ -9,7 +9,7 @@ __all__ = ("AndRestriction", "OrRestriction")
 
 from itertools import islice
 
-from snakeoil.klass import cached_hash, generic_equality
+from snakeoil.klass import cached_hash, generic_equality, immutable
 
 from . import restriction
 
@@ -42,39 +42,32 @@ class base(restriction.base, metaclass=generic_equality):
         :keyword negate: should the logic be negated?
         """
 
-        sf = object.__setattr__
-
         node_type = kwds.pop("node_type", None)
 
-        sf(self, "type", node_type)
-        sf(self, "negate", kwds.pop("negate", False))
+        self.type = node_type
+        self.negate = kwds.pop("negate", False)
 
         if node_type is not None:
             try:
                 for r in restrictions:
                     if r.type is not None and r.type != node_type:
                         raise TypeError(
-                            "instance '%s' is restriction type '%s', "
-                            "must be '%s'" % (r, r.type, node_type)
+                            f"instance '{r}' is restriction type '{r.type}', must be '{node_type}'"
                         )
             except AttributeError:
                 raise TypeError(
-                    "type '%s' instance '%s' has no restriction type, "
-                    "'%s' required" % (r.__class__, r, node_type)
+                    f"type '{r.__class__}' instance '{r}' has no restriction type, '{node_type}' required"
                 )
 
         if kwds.pop("finalize", True):
-            if not isinstance(restrictions, tuple):
-                sf(self, "restrictions", tuple(restrictions))
-            else:
-                sf(self, "restrictions", restrictions)
+            self.restrictions = tuple(restrictions)
         else:
-            sf(self, "restrictions", list(restrictions))
+            self.restrictions = list(restrictions)
 
         if kwds:
             kwds.pop("disable_inst_caching", None)
             if kwds:
-                raise TypeError("unknown keywords to %s: %s" % (self.__class__, kwds))
+                raise TypeError(f"unknown keywords to {self.__class__}: {kwds}")
 
     def change_restrictions(self, *restrictions, **kwds):
         """return a new instance of self.__class__, using supplied restrictions"""
@@ -125,9 +118,10 @@ class base(restriction.base, metaclass=generic_equality):
         except AttributeError:
             raise TypeError("%r is finalized" % self)
 
+    @immutable.Simple.__allow_mutation_wrapper__
     def finalize(self):
         """finalize the restriction instance, disallowing adding restrictions."""
-        object.__setattr__(self, "restrictions", tuple(self.restrictions))
+        self.restrictions = tuple(self.restrictions)
 
     def __repr__(self):
         return "<%s negate=%r type=%r finalized=%r restrictions=%r @%#8x>" % (
@@ -412,7 +406,7 @@ class AndRestriction(base):
 
         if self.negate:
             raise NotImplementedError(
-                "negation for solutions on " "AndRestriction isn't implemented yet"
+                "negation for solutions on AndRestriction isn't implemented yet"
             )
         for x in self.restrictions:
             method = getattr(x, "iter_cnf_solutions", None)
@@ -431,7 +425,7 @@ class AndRestriction(base):
 
         if self.negate:
             raise NotImplementedError(
-                "negation for solutions on " "AndRestriction isn't implemented yet"
+                "negation for solutions on AndRestriction isn't implemented yet"
             )
         andreqs = []
         for x in self.restrictions:
