@@ -4,8 +4,12 @@ import textwrap
 import traceback
 from functools import partial
 
+import snakeoil.formatters
 from snakeoil.errors import dump_error
-from snakeoil.test.mixins import PythonNamespaceWalker
+from snakeoil.klass import get_subclasses_of
+from snakeoil.python_namespaces import import_submodules_of
+
+from pkgcore.config.hint import ConfigHint
 
 from ..config import basics, errors
 from ..ebuild import atom
@@ -128,7 +132,11 @@ classes = subparsers.add_parser(
 
 
 @classes.bind_main_func
-def classes_main(options, out, err):
+def classes_main(
+    options,
+    out: snakeoil.formatters.PlainTextFormatter,
+    _err: snakeoil.formatters.PlainTextFormatter,
+):
     """List all classes referenced by the config."""
     configmanager = options.config
     sections = []
@@ -157,7 +165,11 @@ describe_class.add_argument(
 
 
 @describe_class.bind_main_func
-def describe_class_main(options, out, err):
+def describe_class_main(
+    options,
+    out: snakeoil.formatters.PlainTextFormatter,
+    err: snakeoil.formatters.PlainTextFormatter,
+):
     """Describe the arguments a class needs."""
     try:
         type_obj = basics.ConfigType(options.target_class)
@@ -194,7 +206,7 @@ uncollapsable = subparsers.add_parser(
 
 
 @uncollapsable.bind_main_func
-def uncollapsable_main(options, out, err):
+def uncollapsable_main(options, out: snakeoil.formatters.PlainTextFormatter, _err):
     """Show things that could not be collapsed."""
     config = options.config
     for name in sorted(config.sections()):
@@ -233,13 +245,13 @@ dump.add_argument(
 
 
 @dump.bind_main_func
-def dump_main(options, out, err):
+def dump_main(options, out: snakeoil.formatters.PlainTextFormatter, _err):
     """Dump the entire configuration."""
     config = options.config
     if options.typename is None:
         names = config.sections()
     else:
-        names = iter(getattr(config, options.typename).keys())
+        names = iter(getattr(config.objects, options.typename).keys())
     for i, name in enumerate(sorted(names)):
         if i > 0:
             out.write()
@@ -255,27 +267,14 @@ def dump_main(options, out, err):
 
 
 def all_configurables():
-    class walker(PythonNamespaceWalker):
-
-        ignore_all_import_failures = True
-
-        def _default_module_blacklister(self, target):
-            if (
-                target.startswith(("pkgcore.test.", "pkgcore.plugins."))
-                or "pkgcore.test" == target
-            ):
-                return True
-            return super()._default_module_blacklister(target)
-
-    return (
-        obj
-        for module in walker().walk_namespace("pkgcore")
-        for name in dir(module)
-        if getattr(obj := getattr(module, name), "pkgcore_config_type", None)
-        is not None
-        if not getattr(obj, "disabled", False)
-        if not getattr(obj, "_plugin_disabled_check", lambda: False)()
-    )
+    import_submodules_of(__import__("pkgcore"), dont_try=["pkgcore.test"])
+    # note: just because we said "don't load pkgcore.test" doesn't mean it's not already in
+    # memory due to tests being ran.  Still filter.
+    for cls in get_subclasses_of(object):  # yep, walking the full class hierachy.
+        # TODO: rewrite this to the eventual snakeoil.registry
+        if config_hint := getattr(cls, "pkgcore_config_type", None):
+            assert isinstance(config_hint, ConfigHint)
+            yield cls
 
 
 configurables = subparsers.add_parser(
@@ -294,7 +293,7 @@ configurables.add_argument(
 
 
 @configurables.bind_main_func
-def configurables_main(options, out, err):
+def configurables_main(options, out: snakeoil.formatters.PlainTextFormatter, _err):
     """List registered configurables."""
 
     # try and sort this beast.
@@ -320,29 +319,24 @@ def _dump_uncollapsed_section(config, out, err, section):
         kind, value = section.render_value(config, key, "repr")
         out.write(f"# type: {kind}")
         if kind == "list":
-            for name, val in zip((key + ".prepend", key, key + ".append"), value):
-                if val:
-                    out.write(repr(name), " = ", " ".join(repr(v) for v in val))
+            out.write(repr(key), " = ", " ".join(repr(v) for v in value))
             continue
         if kind in ("refs", "str"):
-            for name, val in zip((key + ".prepend", key, key + ".append"), value):
-                if not val:
-                    continue
-                out.write(repr(name), " = ", autoline=False)
-                if kind == "str":
-                    out.write(repr(val))
-                else:
-                    out.write()
-                    out.first_prefix.append("    ")
-                    try:
-                        for subnr, subsection in enumerate(val):
-                            subname = f"nested section {subnr + 1}"
-                            out.write(subname)
-                            out.write("=" * len(subname))
-                            _dump_uncollapsed_section(config, out, err, subsection)
-                            out.write()
-                    finally:
-                        out.first_prefix.pop()
+            out.write(repr(key), " = ", autoline=False)
+            if kind == "str":
+                out.write(repr(value))
+            else:
+                out.write()
+                out.first_prefix.append("    ")
+                try:
+                    for subnr, subsection in enumerate(value):
+                        subname = f"nested section {subnr + 1}"
+                        out.write(subname)
+                        out.write("=" * len(subname))
+                        _dump_uncollapsed_section(config, out, err, subsection)
+                        out.write()
+                finally:
+                    out.first_prefix.pop()
             continue
         out.write(f"{key!r} = ", autoline=False)
         if kind == "callable":
@@ -372,7 +366,11 @@ dump_uncollapsed = subparsers.add_parser(
 
 
 @dump_uncollapsed.bind_main_func
-def dump_uncollapsed_main(options, out, err):
+def dump_uncollapsed_main(
+    options,
+    out: snakeoil.formatters.PlainTextFormatter,
+    err: snakeoil.formatters.PlainTextFormatter,
+):
     """dump the configuration in a raw, uncollapsed form.
     Not directly usable as a configuration file, mainly used for inspection
     """
@@ -416,7 +414,11 @@ commandline.make_query(
 
 
 @package.bind_main_func
-def package_func(options, out, err):
+def package_func(
+    options,
+    out: snakeoil.formatters.PlainTextFormatter,
+    _err: snakeoil.formatters.PlainTextFormatter,
+):
     matched = True
     domain = options.domain
     for pkg in domain.installed_repos.combined.itermatch(options.query):
@@ -474,7 +476,11 @@ world.set_defaults(
 
 
 @world.bind_main_func
-def world_func(options, out, err):
+def world_func(
+    options,
+    out: snakeoil.formatters.PlainTextFormatter,
+    _err: snakeoil.formatters.PlainTextFormatter,
+):
     world_file = options.world
 
     if options.remove:
