@@ -11,7 +11,7 @@ from textwrap import dedent
 from time import time
 
 from snakeoil.cli.exceptions import ExitException
-from snakeoil.sequences import iflatten_instance, stable_unique
+from snakeoil.sequences import iflatten_instance, unique_stable
 from snakeoil.strings import pluralism
 
 from ..config.basics import ConfigSectionFromStringDict
@@ -648,7 +648,7 @@ def _validate(parser, namespace):
         parser.error("-O/--nodeps cannot be used with -o/--onlydeps (it's a no-op)")
 
     if namespace.sets:
-        unknown_sets = set(namespace.sets).difference(namespace.config.pkgset)
+        unknown_sets = set(namespace.sets).difference(namespace.config.objects.pkgset)
         if unknown_sets:
             parser.error(
                 "unknown set%s: %s (available sets: %s)"
@@ -658,7 +658,9 @@ def _validate(parser, namespace):
                     ", ".join(sorted(namespace.config.pkgset)),
                 )
             )
-        namespace.sets = [(x, namespace.config.pkgset[x]) for x in namespace.sets]
+        namespace.sets = [
+            (x, namespace.config.objects.pkgset[x]) for x in namespace.sets
+        ]
     if namespace.upgrade or namespace.downgrade:
         namespace.replace = False
     if not namespace.targets and not namespace.sets:
@@ -738,7 +740,7 @@ def parse_target(restriction, repo, installed_repos, return_none=False):
 
 @argparser.bind_delayed_default(50, name="world")
 def load_world(namespace, attr):
-    value = namespace.config.pkgset["world"]
+    value = namespace.config.objects.pkgset["world"]
     setattr(namespace, attr, value)
 
 
@@ -790,7 +792,7 @@ def main(options, out, err):
         if not options.oneshot:
             if world_set is None:
                 argparser.error(
-                    "disable world updating via --oneshot, " "or fix your configuration"
+                    "disable world updating via --oneshot, or fix your configuration"
                 )
         try:
             unmerge(
@@ -841,7 +843,7 @@ def main(options, out, err):
         if matches is None:
             if not options.ignore_failures:
                 error_msg = [f"no matching {pkg_type}: {token!r}"]
-                if token in config.pkgset:
+                if token in config.objects.pkgset:
                     error_msg.append(f"use '@{token}' instead for the package set")
                 elif options.usepkgonly:
                     matches = parse_target(
@@ -863,7 +865,7 @@ def main(options, out, err):
         err.write(f"{options.prog}: no targets specified; nothing to do")
         return 1
 
-    atoms = stable_unique(atoms)
+    atoms = unique_stable(atoms)
     if options.force_stable_ordering_of_targets:
         atoms = sorted(atoms)
 
