@@ -1,6 +1,7 @@
 from random import shuffle
 
 import pytest
+
 from pkgcore.ebuild import cpv
 
 
@@ -20,19 +21,25 @@ def generate_misc_sufs():
 
 class TestCPV:
     good_cats = (
+        # see https://github.com/pkgcore/pkgcore/issues/453 .  PMS regex broke from pre spec allowing some weird stuff.
         "dev-util",
         "dev+",
-        "dev-util+",
-        "DEV-UTIL",
+        "DEV-UTIL+",
         "aaa0",
         "aaa-0",
-        "multi/depth",
-        "cross-dev_idiot.hacks-suck",
-        "a",
-        "foo---",
         "multi--hyphen",
+        "_dev",
+        "_",  # yep, that's legal.
+    )
+    bad_cats = (
+        "",
+        "-",
+        "+",
+        "dev-util ",
+        "multi/blah/depth",
+        "multi//depth",
+        "reject.a",
     )
-    bad_cats = (".util", "_dev", "", "dev-util ", "multi//depth")
     good_pkgs = (
         "diffball",
         "a9",
@@ -147,6 +154,14 @@ class TestCPV:
                 f"1{'0' * x}1"
             )
 
+    def test_parsing_recursion_gh459(self):
+        # if it hangs, it failed.
+        self.process_pkg(
+            True,
+            "dev-java",
+            "log5j-777777777777777777777777777777777-777777777777777777-7777777777777777777-7777777-7dev-q!7778/qt77ased-77",
+        )
+
     def process_pkg(self, ret, cat, pkg):
         if ret:
             with pytest.raises(cpv.InvalidCPV):
