@@ -2,6 +2,7 @@ import shutil
 from unittest import mock
 
 import pytest
+
 from pkgcore.const import EBD_PATH
 from pkgcore.ebuild import eapi
 from pkgcore.ebuild.eapi import EAPI, eapi6, get_eapi
@@ -43,13 +44,13 @@ class TestEAPI:
             # adequate system bash versions
             bash_version.return_value = "3.2"
             test_eapi = EAPI.register(magic="test", optionals={"bash_compat": "3.2"})
-            assert test_eapi._magic == "test"
+            assert test_eapi.magic == "test"
             bash_version.return_value = "4.2"
             test_eapi = EAPI.register(magic="test1", optionals={"bash_compat": "4.1"})
-            assert test_eapi._magic == "test1"
+            assert test_eapi.magic == "test1"
 
-    def test_is_supported(self, tmp_path, caplog):
-        assert eapi6.is_supported
+    def test_supported(self, tmp_path, caplog):
+        assert eapi6.supported
 
         mock_ebd_temp = str(shutil.copytree(EBD_PATH, tmp_path / "ebd"))
         with (
@@ -57,13 +58,13 @@ class TestEAPI:
             mock.patch("pkgcore.ebuild.eapi.const.EBD_PATH", mock_ebd_temp),
         ):
             # partially supported EAPI is flagged as such
-            test_eapi = EAPI.register("test", optionals={"is_supported": False})
-            assert test_eapi.is_supported
+            test_eapi = EAPI.register("test", optionals={"supported": False})
+            assert test_eapi.supported
             assert caplog.text.endswith("EAPI 'test' isn't fully supported\n")
 
             # unsupported/unknown EAPI is flagged as such
             unknown_eapi = get_eapi("blah")
-            assert not unknown_eapi.is_supported
+            assert not unknown_eapi.supported
 
     def test_inherits(self):
         for eapi_str, eapi_obj in EAPI.known_eapis.items():
