@@ -1,4 +1,5 @@
 import textwrap
+from contextlib import chdir
 from pathlib import Path
 
 import pytest
@@ -7,7 +8,6 @@ from pkgcore.ebuild import eclass_cache
 from pkgcore.ebuild import repository, restricts
 from pkgcore.ebuild.atom import atom
 from pkgcore.repository import errors
-from snakeoil.contexts import chdir
 
 
 class TestUnconfiguredTree:
