@@ -265,11 +265,11 @@ class TestUncollapsable(ArgParseMixin):
             [
                 "section foon:",
                 " Collapsing section named 'foon'",
-                " cannot collapse inherit-only section" "",
+                " cannot collapse inherit-only section",
                 "",
                 "section spork:",
                 " Collapsing section named 'spork'",
-                " type tests.scripts.test_pconfig.spork needs settings for 'reff'" "",
+                " type tests.scripts.test_pconfig.spork needs settings for 'reff'",
                 "",
             ],
             spork=basics.HardCodedConfigSection({"class": spork}),
