@@ -12,10 +12,9 @@ existing_uid = pwd.getpwnam(existing_user).pw_uid
 
 
 class TestSyncer:
-
     @pytest.fixture(autouse=True)
     def _setup(self, tmp_path):
-        self.repo_path = str(tmp_path / 'repo')
+        self.repo_path = str(tmp_path / "repo")
 
     def test_split_users(self):
         o = base.Syncer(self.repo_path, "http://dar")
@@ -37,23 +36,23 @@ class TestSyncer:
         with pytest.raises(base.MissingLocalUser):
             base.Syncer(self.repo_path, f"foo_nonexistent_user::foon@site")
 
-    @mock.patch('snakeoil.process.spawn.spawn')
+    @mock.patch("snakeoil.process.spawn.spawn")
     def test_usersync_disabled(self, spawn):
         o = base.Syncer(self.repo_path, f"http://foo/bar.git", usersync=False)
         o.uid == os_data.uid
         o.gid == os_data.gid
 
-    @mock.patch('snakeoil.process.spawn.spawn')
+    @mock.patch("snakeoil.process.spawn.spawn")
     def test_usersync_portage_perms(self, spawn):
         # sync uses portage perms if repo dir doesn't exist
         o = base.Syncer(self.repo_path, f"http://foo/bar.git", usersync=True)
         o.uid == os_data.portage_uid
         o.gid == os_data.portage_gid
 
-    @mock.patch('snakeoil.process.spawn.spawn')
+    @mock.patch("snakeoil.process.spawn.spawn")
     def test_usersync_repo_dir_perms(self, spawn):
         # and repo dir perms if it does exist
-        with mock.patch('os.stat') as stat:
+        with mock.patch("os.stat") as stat:
             stat.return_value = mock.Mock(st_uid=1234, st_gid=5678)
             o = base.Syncer(self.repo_path, f"http://foo/bar.git", usersync=True)
             stat.assert_called()
@@ -61,62 +60,60 @@ class TestSyncer:
             assert o.gid == 5678
 
 
-@mock.patch('snakeoil.process.find_binary')
+@mock.patch("snakeoil.process.find_binary")
 class TestExternalSyncer:
-
     @pytest.fixture(autouse=True)
     def _setup(self, tmp_path):
-        self.repo_path = str(tmp_path / 'repo')
+        self.repo_path = str(tmp_path / "repo")
 
     def test_missing_binary(self, find_binary):
-        find_binary.side_effect = CommandNotFound('foo')
+        find_binary.side_effect = CommandNotFound("foo")
         with pytest.raises(base.MissingBinary):
-            base.ExternalSyncer(self.repo_path, 'http://dar')
+            base.ExternalSyncer(self.repo_path, "http://dar")
 
     def test_existing_binary(self, find_binary):
         # fake external syncer
         class FooSyncer(base.ExternalSyncer):
-            binary = 'foo'
+            binary = "foo"
 
         # fake that the external binary exists
         find_binary.side_effect = lambda x: x
 
-        o = FooSyncer(self.repo_path, 'http://dar')
-        assert o.uri == 'http://dar'
-        assert o.binary == 'foo'
+        o = FooSyncer(self.repo_path, "http://dar")
+        assert o.uri == "http://dar"
+        assert o.binary == "foo"
 
-    @mock.patch('snakeoil.process.spawn.spawn')
+    @mock.patch("snakeoil.process.spawn.spawn")
     def test_usersync(self, spawn, find_binary):
         # fake external syncer
         class FooSyncer(base.ExternalSyncer):
-            binary = 'foo'
+            binary = "foo"
 
         # fake that the external binary exists
         find_binary.side_effect = lambda x: x
 
-        o = FooSyncer(self.repo_path, 'http://dar')
+        o = FooSyncer(self.repo_path, "http://dar")
         o.uid = 1234
         o.gid = 2345
-        o._spawn('cmd', pipes={})
-        assert spawn.call_args[1]['uid'] == o.uid
-        assert spawn.call_args[1]['gid'] == o.gid
+        o._spawn("cmd", pipes={})
+        assert spawn.call_args[1]["uid"] == o.uid
+        assert spawn.call_args[1]["gid"] == o.gid
 
 
-@mock.patch('snakeoil.process.find_binary', return_value='git')
-@mock.patch('snakeoil.process.spawn.spawn')
+@mock.patch("snakeoil.process.find_binary", return_value="git")
+@mock.patch("snakeoil.process.spawn.spawn")
 class TestVcsSyncer:
-
     def test_basedir_perms_error(self, spawn, find_binary, tmp_path):
-        syncer = git.git_syncer(str(tmp_path), 'git://blah.git')
+        syncer = git.git_syncer(str(tmp_path), "git://blah.git")
         with pytest.raises(base.PathError):
-            with mock.patch('os.stat') as stat:
-                stat.side_effect = EnvironmentError('fake exception')
+            with mock.patch("os.stat") as stat:
+                stat.side_effect = EnvironmentError("fake exception")
                 syncer.sync()
 
     def test_basedir_is_file_error(self, spawn, find_binary, tmp_path):
         repo = tmp_path / "repo"
         repo.touch()
-        syncer = git.git_syncer(str(repo), 'git://blah.git')
+        syncer = git.git_syncer(str(repo), "git://blah.git")
 
         # basedir gets '/' appended by default and stat errors out
         with pytest.raises(base.PathError) as excinfo:
@@ -129,32 +126,30 @@ class TestVcsSyncer:
         assert "isn't a directory" in str(excinfo.value)
 
     def test_verbose_sync(self, spawn, find_binary, tmp_path):
-        syncer = git.git_syncer(str(tmp_path), 'git://blah.git')
+        syncer = git.git_syncer(str(tmp_path), "git://blah.git")
         syncer.sync(verbosity=1)
-        assert '-v' == spawn.call_args[0][0][-1]
+        assert "-v" == spawn.call_args[0][0][-1]
         syncer.sync(verbosity=2)
-        assert '-vv' == spawn.call_args[0][0][-1]
+        assert "-vv" == spawn.call_args[0][0][-1]
 
     def test_quiet_sync(self, spawn, find_binary, tmp_path):
-        syncer = git.git_syncer(str(tmp_path), 'git://blah.git')
+        syncer = git.git_syncer(str(tmp_path), "git://blah.git")
         syncer.sync(verbosity=-1)
-        assert '-q' == spawn.call_args[0][0][-1]
+        assert "-q" == spawn.call_args[0][0][-1]
 
 
 class TestGenericSyncer:
-
     def test_init(self):
         with pytest.raises(base.UriError):
-            base.GenericSyncer('/', 'seriouslynotaprotocol://blah/')
+            base.GenericSyncer("/", "seriouslynotaprotocol://blah/")
 
-        syncer = base.GenericSyncer('/', f'tar+https://blah.tar.gz')
+        syncer = base.GenericSyncer("/", f"tar+https://blah.tar.gz")
         assert tar.tar_syncer is syncer.__class__
 
 
 class TestDisabledSyncer:
-
     def test_init(self):
-        syncer = base.DisabledSyncer('/foo/bar', f'https://blah.git')
+        syncer = base.DisabledSyncer("/foo/bar", f"https://blah.git")
         assert syncer.disabled
         # syncing should also be disabled
         assert not syncer.uri
@@ -162,14 +157,13 @@ class TestDisabledSyncer:
 
 
 class TestAutodetectSyncer:
-
     def test_no_syncer_detected(self, tmp_path):
         syncer = base.AutodetectSyncer(str(tmp_path))
         assert isinstance(syncer, base.DisabledSyncer)
 
-    @mock.patch('snakeoil.process.find_binary', return_value='git')
+    @mock.patch("snakeoil.process.find_binary", return_value="git")
     def test_syncer_detected(self, find_binary, tmp_path):
-        d = tmp_path / '.git'
+        d = tmp_path / ".git"
         d.mkdir()
         syncer = base.AutodetectSyncer(str(tmp_path))
         assert isinstance(syncer, git.git_syncer)
